"""[Optional] Construct agents required by the Sample Cast graph.

Guidelines:
    - Create agents using the `langchain.agents` module.
    - Reuse components defined in `modules.prompts` and `modules.models`.4

Official document URL:
    - Agents: https://docs.langchain.com/oss/python/langchain/agents
    - Built-in Middleware: https://docs.langchain.com/oss/python/langchain/middleware/built-in
"""

# from langchain.agents import create_agent
# from .models import get_sample_model
# from .prompts import get_sample_prompt
# from .tools import get_sample_tools
# from .middleware import get_sample_middleware


def set_sample_agent():
    # return create_agent(
    #     model=get_sample_model(),
    #     tools=[],
    #     middleware=[],
    #     system_prompt=prompt,
    # )
    pass
