"""[Optional] Model configuration helpers for the {{ cookiecutter.cast_name }} graph.

Guidelines:
    - Provide factory functions for LLMs or embeddings.
    - Accept environment variables or configuration values when necessary.

Official document URL:
    - Models: https://docs.langchain.com/oss/python/langchain/models
    - Chat Models: https://docs.langchain.com/oss/python/integrations/chat
    - Embedding Models: https://docs.langchain.com/oss/python/integrations/text_embedding
"""

# from langchain.chat_models import init_chat_model
# from langchain_openai import ChatOpenAI


def get_sample_model():
    # return init_chat_model(
    #     model="",
    #     model_provider="openai",
    # )
    pass
